@@ -1,5 +1,5 @@
 
-# $Id: parm.R 229 2008-04-04 11:47:30Z thothorn $
+# $Id: parm.R 243 2008-07-22 16:33:38Z thothorn $
 
 parm <- function(coef, vcov, df = 0) {
 
@@ -20,8 +20,8 @@ parm <- function(coef, vcov, df = 0) {
     if (!is.numeric(vcov) || !is.matrix(vcov))
         stop(sQuote("vcov"), " is not a numeric matrix")
 
-    if (max(abs(vcov - t(vcov))) > .Machine$double.eps)
-        stop(sQuote("vcov"), " is not symmetric")
+    if (!isSymmetric(vcov, tol = sqrt(.Machine$double.eps)))
+        stop(sQuote("vcov"), " is not a symmetric matrix")
 
     ret <- list(coef = coef, vcov = vcov, df = df)
     class(ret) <- "parm"
